/*
 * Generated source file, not in CVS/SVN repository
 */
package org.jcoderz.commons.connector.http.transport;


import java.io.Serializable;
import java.util.Arrays;
import java.util.Collections;
import java.util.Map;
import java.util.HashMap;
import java.util.List;


import org.jcoderz.commons.ArgumentMalformedException;


/**
 * Enumerated type of a http connection state.
 *
 * Instances of this class are immutable.
 *
 * The following http connection states are defined:
 * <ul>
 *    <li>HttpConnectionState.CONNECTION_NOT_ESTABLISHED = 'connection not established'</li>
 *    <li>HttpConnectionState.CONNECTION_ESTABLISHED = 'connection established'</li>
 *    <li>HttpConnectionState.CONNECTION_EXECUTED = 'connection executed'</li>
 *    <li>HttpConnectionState.CONNECTION_RELEASED = 'connection released'</li>
 *    <li>HttpConnectionState.CONNECTION_CLOSED = 'connection closed'</li>
 * </ul>
 *
 * 
 * The values of this enum have a internal
 * sequential integer representation starting with '0'.
 *
 * @author generated
 */
public final class HttpConnectionState
        implements Serializable, org.jcoderz.commons.EnumType
{
   /**
    * The name of this type.
    */
   public static final String TYPE_NAME = "HttpConnectionState";

   /** Ordinal of next http connection state to be created. */
   private static int sNextOrdinal = 0;

   /** Maps a string representation to an enumerated value. */
   private static final Map<String, HttpConnectionState>
      FROM_STRING = new HashMap<String, HttpConnectionState>();

   /** The HttpConnectionState connection not established. */
   public static final HttpConnectionState CONNECTION_NOT_ESTABLISHED
      = new HttpConnectionState("connection not established");

   /** The HttpConnectionState connection established. */
   public static final HttpConnectionState CONNECTION_ESTABLISHED
      = new HttpConnectionState("connection established");

   /** The HttpConnectionState connection executed. */
   public static final HttpConnectionState CONNECTION_EXECUTED
      = new HttpConnectionState("connection executed");

   /** The HttpConnectionState connection released. */
   public static final HttpConnectionState CONNECTION_RELEASED
      = new HttpConnectionState("connection released");

   /** The HttpConnectionState connection closed. */
   public static final HttpConnectionState CONNECTION_CLOSED
      = new HttpConnectionState("connection closed");


   /** The serialVersionUID used for serialization. */
   static final long serialVersionUID = 1;

   /** Internal list of all available HttpConnectionStates */
   private static final HttpConnectionState[] PRIVATE_VALUES
         =
            {
               HttpConnectionState.CONNECTION_NOT_ESTABLISHED,
               HttpConnectionState.CONNECTION_ESTABLISHED,
               HttpConnectionState.CONNECTION_EXECUTED,
               HttpConnectionState.CONNECTION_RELEASED,
               HttpConnectionState.CONNECTION_CLOSED
            };

   /** Immutable list of the HttpConnectionStates. */
   public static final List VALUES
         = Collections.unmodifiableList(Arrays.asList(PRIVATE_VALUES));

   /**
    * Immutable map using the name string as key holding the
    * HttpConnectionStates as values.
    */
   public static final Map VALUE_MAP
         = Collections.unmodifiableMap(FROM_STRING);

   /** Assign a ordinal to this http connection state */
   private final int mOrdinal = sNextOrdinal++;

   /** The name of the http connection state */
   private final transient String mName;

   /** Private Constructor */
   private HttpConnectionState (String name)
   {
      mName = name;
      FROM_STRING.put(mName, this);
   }


   /**
    * Creates a HttpConnectionState object from its int representation.
    *
    * @param i the integer representation of the http connection state.
    * @return the HttpConnectionState object represented by this int.
    * @throws ArgumentMalformedException If the assigned int value isn't
    *       listed in the internal http connection state table.
    */
   public static HttpConnectionState fromInt (int i)
         throws ArgumentMalformedException
   {
      try
      {
         return PRIVATE_VALUES[i];
      }
      catch (ArrayIndexOutOfBoundsException e)
      {
         throw new ArgumentMalformedException(
               "HttpConnectionState",
               new Integer(i),
               "Illegal int representation of HttpConnectionState.");
      }
   }


   /**
    * Creates a HttpConnectionState object from its String representation.
    *
    * @param str the string representation of the
    *       http connection state.
    * @return the HttpConnectionState object represented by this str.
    * @throws ArgumentMalformedException If the given str value isn't
    *       listed in the internal http connection state table.
    */
   public static HttpConnectionState fromString (String str)
         throws ArgumentMalformedException
   {
      final HttpConnectionState result
            = (HttpConnectionState) FROM_STRING.get(str);
      if (result == null)
      {
         throw new ArgumentMalformedException(
               "HttpConnectionState",
               str,
               "Illegal string representation of HttpConnectionState, only "
                  + VALUES + " are allowed.");
      }
      return result;
   }

   /**
    * Returns the int representation of this http connection state.
    *
    * @return the int representation of this http connection state.
    */
   public int toInt ()
   {
        return mOrdinal;
   }

   /**
    * Returns the String representation of this http connection state.
    *
    * @return the String representation of this http connection state.
    */
   public String toString ()
   {
      return mName;
   }

   /**
    * Resolves instances being deserialized to a single instance
    * per http connection state.
    */
   private Object readResolve ()
   {
      return PRIVATE_VALUES[mOrdinal];
   }
}
